import 'package:flutter/material.dart';
import '../../common/values/sizes.dart';
import '../../remote/model/application_config.dart';
import '../custom/custom_background_gradient.dart';
import '../custom/spaces.dart';
import '../text/custom_text_large_bold_field.dart';

class CustomAppBar extends StatefulWidget {
  final String title;
  final Widget? tabBarMenu;
  final Widget? tabBarMenuRight;
  final bool? isShowShadow;
  final ApplicationConfig? applicationConfig;

  const CustomAppBar({
    required this.title,
    this.tabBarMenu,
    this.tabBarMenuRight,
    this.isShowShadow = false,
    this.applicationConfig,
  });

  @override
  State<CustomAppBar> createState() => _CustomAppBarState();
}

class _CustomAppBarState extends State<CustomAppBar> {
  @override
  Widget build(BuildContext context) {
    return CustomBackgroundGradient(
      applicationConfig: widget.applicationConfig,
      child: SafeArea(
        maintainBottomViewPadding: false,
        bottom: false,
        child: Column(
          children: [
            Container(
              child: Padding(
                padding: EdgeInsets.only(left: 20),
                child: Column(
                  children: [
                    SizedBox(
                      height: Sizes.HEIGHT_52,
                      child: Row(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: <Widget>[
                          CustomTextLargeBoldField(
                            label: widget.title,
                            color: Colors.white,
                          ),
                          Padding(
                            padding: const EdgeInsets.only(right: 12),
                            child: widget.tabBarMenuRight ?? Container(),
                          ),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ),
            widget.tabBarMenu ?? Container(),
            if (widget.isShowShadow == true) ...{SpaceShadowBottom()}
          ],
        ),
      ),
    );
  }
}
