import 'package:flutter/material.dart';

import '../../common/values/sizes.dart';
import '../custom/custom_icon.dart';
import '../custom/spaces.dart';
import '../dialog/custom_will_pop_back.dart';
import '../text/custom_text_large_bold_field.dart';

class CustomAppBarArrow extends StatelessWidget {
  final String title;
  final Widget? tabBarMenu;
  final Widget? tabBarMenuRight;
  final bool? isShowShadow;
  final bool? isWarning;
  final Color? color;
  final Color? textColor;

  const CustomAppBarArrow(
      {required this.title,
      this.tabBarMenu,
      this.color = Colors.white,
      this.textColor,
      this.isShowShadow = false,
      this.isWarning = false,
      this.tabBarMenuRight});

  @override
  Widget build(BuildContext context) {
    return Container(
      color: color,
      child: Column(
        children: [
          SafeArea(
            maintainBottomViewPadding: false,
            bottom: false,
            child: Container(
              child: Padding(
                padding: EdgeInsets.only(left: 10),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.stretch,
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    SizedBox(
                      height: Sizes.HEIGHT_52,
                      child: GestureDetector(
                        onTap: () => CustomWillPopBack.Pop(context, isWarning),
                        child: Row(
                          crossAxisAlignment: CrossAxisAlignment.center,
                          mainAxisAlignment: MainAxisAlignment.start,
                          children: <Widget>[
                            Container(
                              child: Container(
                                  decoration: BoxDecoration(
                                      borderRadius: BorderRadius.circular(100)),
                                  child: CustomIcon(
                                    icon: Icons.keyboard_arrow_left_outlined,
                                    color: textColor ?? Colors.black,
                                    size: 36,
                                  )),
                            ),
                            Expanded(
                              child: CustomTextLargeBoldField(
                                label: title,
                                color: textColor,
                              ),
                            ),
                            Padding(
                              padding: const EdgeInsets.only(right: 8),
                              child: tabBarMenuRight ?? Container(),
                            )
                          ],
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
          tabBarMenu ?? Container(),
          if (isShowShadow == true) ...{SpaceShadowBottom()}
        ],
      ),
    );
  }
}
