import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:sharing/remote/local/shared_prefers_helper.dart';

// ignore: must_be_immutable
class SafeImage extends StatelessWidget {
  SafeImage(
      {required this.imageUrl,
      this.width = 0,
      this.height = 0,
      this.radius = 8,
      this.boxfit = BoxFit.cover,
      this.color});

  final String? imageUrl;
  double width;
  double height;
  final double radius;
  final BoxFit boxfit;
  final Color? color;

  @override
  Widget build(BuildContext context) {
    return ClipRRect(
        borderRadius: BorderRadius.circular(radius),
        child: getImage(imageUrl ?? ""));
  }

  Widget getImage(String imageUrl) {
    try {
      if (imageUrl.isNotEmpty == true) {
        if (imageUrl.contains("assets") == true) {
          return getImageSvg(imageUrl);
        } else {
          return getImageFromServer(imageUrl);
        }
      } else {
        return getImageNotFound();
      }
    } catch (e) {
      return getImageBlank();
    }
  }

  Widget getImageFromServer(String url) {
    var urlServer = prefsHelper.getImageUrl();
    if (width == 0 || height == 0) {
      return AspectRatio(
          aspectRatio: 1,
          child: CachedNetworkImage(
            imageUrl: "$urlServer${url}",
            placeholder: (context, url) => getImageBlank(),
            errorWidget: (context, url, error) => getImageNotFound(),
            fit: boxfit,
          ));
    } else {
      return CachedNetworkImage(
        width: width,
        height: height,
        imageUrl: "$urlServer${url}",
        placeholder: (context, url) => getImageBlank(),
        errorWidget: (context, url, error) => getImageNotFound(),
        fit: boxfit,
      );
    }
  }

  Widget getImageSvg(String url) {
    if (width == 0 || height == 0) {
      return AspectRatio(
        aspectRatio: 1,
        child: Image.asset(
          url,
          fit: boxfit,
          color: color,
        ),
      );
    } else {
      return Image.asset(
        url,
        width: width,
        height: height,
        fit: boxfit,
        color: color,
      );
    }
  }

  Widget getImageNotFound() {
    if (width == 0 || height == 0) {
      return AspectRatio(
        aspectRatio: 1,
        child: Image.asset(
          "assets/images/image_not_found.png",
          fit: BoxFit.cover,
        ),
      );
    } else {
      return Image.asset(
        "assets/images/image_not_found.png",
        width: width,
        height: height,
        fit: BoxFit.cover,
      );
    }
  }

  Widget getImageBlank() {
    // return BlankContainer(
    //   width: width,
    //   height: height,
    //   radius: radius
    // );
    return Image.asset(
      "assets/images/image_not_found.png",
      width: width,
      height: height,
      fit: BoxFit.cover,
    );
  }
}
